# pygme
CLI games written in native Python

# Installing
#### From git clone
```
bash install.sh
```
#### From pypi
```
pip3 install pygme
```

# Playing
See what's available
```
pygme -h
```
Choose game
```
pygme snake
```
Configure game by answering prompted questions and play!

![A CLI Snake game](https://media.giphy.com/media/QLR9DHzeoqJgihomeM/giphy.gif)
